@@ -1,7 +1,7 @@
 /*
  * Make7Libre, free (as in freedom) implementation of the
  * unfamous game 'Make 7 Hexa Puzzle'
- * Copyright 2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
+ * Copyright 2016-2017 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  * 
  * This file is part of Make7Libre.
  * 
@@ -23,8 +23,9 @@
  * ~~~~~~~ *
  ***********/
 
-#include <iostream>
-#include <stdlib.h>
+#include <iostream>  // cout, cin...
+#include <stdlib.h>  // srand, rand
+#include <ctime>     // ctime
 #include <gtkmm.h>
 #include "../include/game.h"
 
@@ -36,8 +37,7 @@ main (int argc, char** argv)
     Gtk::Application::create (argc, argv, "org.gtkmm.example");
   Game* game = new Game ();
   /* Seeding the random */
-  // TODO
-  //  std::seed (128);
+  srand (time (NULL));
   /* Importation */
   game->import_every_widget ();
   /* Connexion */
